#  _________________________________________________________________________
#
#  Coopr: A COmmon Optimization Python Repository
#  Copyright (c) 2010 Sandia Corporation.
#  This software is distributed under the BSD License.
#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
#  the U.S. Government retains certain rights in this software.
#  For more information, see the Coopr README.txt file.
#  _________________________________________________________________________
#
#  Formulated in pyomo by Logan Barnes and Gabe Hackebeil. 
#
#  Taken from:

#
#**************************
# SET UP THE INITIAL DATA *
#**************************
#   Problem :
#   *********
#   A problem freely inspired by the heavy spacecraft landing problem by
#   Ivashkevich, as reported by Tyatushkin, Zholudev and Erinchek.  The
#   modifications of the original problem involves dropping the final state
#   constraint on the second variable and the setting of EPS to zero
#   in the second constraint. 
#   (No feasible point was found for the original formulation by any of the
#   packages at hand.)
#   This is a badly scaled degenerate nonlinear nonconvex optimal control 
#   problem, with lots of negative curvature.
#   Source: inspired by
#   A.I Tyatushkin, A.I. Zholudev and N. M. Erinchek,
#   "The gradient method for solving optimal control problems with phase
#   constraints", 
#   in "System Modelling and Optimization", P. Kall, ed., pp. 456--464,
#   Springer Verlag, Lecture Notes in Control and Information Sciences 180, 1992.
#   This reference itself refers to:
#   A.K. Ivashkevich,
#   "Multistage US spacecraft Space Shuttle", 
#   Survey of foreign papers (Part 11),  Orbital Craft, Moscow, 1976.
#   SIF input: Ph. Toint, February 1994.
#   classification LOR2-AN-V-V
#   Number of discretized points in (0,TT].
#   The number of variables is    4 * ( N + 1 )
#   The number of constraints is  3 * N
#IE N                   100            $ n =  404, m =  300
#IE N                   500            $ n = 2004, m = 1500
#IE N                   1000           $ n = 4004, m = 3000
#   Problem parameters
#   Mesh
#   Constants
#   State variables
#   Control variables
#   Objective function
#   State constraints
#   State constraints elements
#   State constraints
# ZE C(2,T)    E2(T)                    -H
# ZE C(2,T)    E3(T)                    -H
#   Solution
#LO SOLTN             -0.21850
#LO SOLTN(100)        3.26705331D-8
#LO SOLTN(500)        2.36171208D-8
#LO SOLTN(1000)       8.48265630D-8

from coopr.pyomo import *
model = ConcreteModel()
n = 50.0
tt = 0.2185
eps = 0.1
alpha = 1.62079
nm1 = -1.0 + (50.0)
rn = 50.0
h = (0.2185) / (50.0)
tm1 = -1.0 + (50.0)

model.x1_0 = Var(bounds=(0.0,0.0))
model.x2_0 = Var(initialize=2.19905,bounds=(2.19905,2.19905))
model.x3_0 = Var(bounds=(0.0,6.2831854))
model.x1_1 = Var()
model.x2_1 = Var(initialize=1.5)
model.x3_1 = Var(bounds=(0.0,6.2831854))
model.x1_2 = Var()
model.x2_2 = Var(initialize=1.5)
model.x3_2 = Var(bounds=(0.0,6.2831854))
model.x1_3 = Var()
model.x2_3 = Var(initialize=1.5)
model.x3_3 = Var(bounds=(0.0,6.2831854))
model.x1_4 = Var()
model.x2_4 = Var(initialize=1.5)
model.x3_4 = Var(bounds=(0.0,6.2831854))
model.x1_5 = Var()
model.x2_5 = Var(initialize=1.5)
model.x3_5 = Var(bounds=(0.0,6.2831854))
model.x1_6 = Var()
model.x2_6 = Var(initialize=1.5)
model.x3_6 = Var(bounds=(0.0,6.2831854))
model.x1_7 = Var()
model.x2_7 = Var(initialize=1.5)
model.x3_7 = Var(bounds=(0.0,6.2831854))
model.x1_8 = Var()
model.x2_8 = Var(initialize=1.5)
model.x3_8 = Var(bounds=(0.0,6.2831854))
model.x1_9 = Var()
model.x2_9 = Var(initialize=1.5)
model.x3_9 = Var(bounds=(0.0,6.2831854))
model.x1_10 = Var()
model.x2_10 = Var(initialize=1.5)
model.x3_10 = Var(bounds=(0.0,6.2831854))
model.x1_11 = Var()
model.x2_11 = Var(initialize=1.5)
model.x3_11 = Var(bounds=(0.0,6.2831854))
model.x1_12 = Var()
model.x2_12 = Var(initialize=1.5)
model.x3_12 = Var(bounds=(0.0,6.2831854))
model.x1_13 = Var()
model.x2_13 = Var(initialize=1.5)
model.x3_13 = Var(bounds=(0.0,6.2831854))
model.x1_14 = Var()
model.x2_14 = Var(initialize=1.5)
model.x3_14 = Var(bounds=(0.0,6.2831854))
model.x1_15 = Var()
model.x2_15 = Var(initialize=1.5)
model.x3_15 = Var(bounds=(0.0,6.2831854))
model.x1_16 = Var()
model.x2_16 = Var(initialize=1.5)
model.x3_16 = Var(bounds=(0.0,6.2831854))
model.x1_17 = Var()
model.x2_17 = Var(initialize=1.5)
model.x3_17 = Var(bounds=(0.0,6.2831854))
model.x1_18 = Var()
model.x2_18 = Var(initialize=1.5)
model.x3_18 = Var(bounds=(0.0,6.2831854))
model.x1_19 = Var()
model.x2_19 = Var(initialize=1.5)
model.x3_19 = Var(bounds=(0.0,6.2831854))
model.x1_20 = Var()
model.x2_20 = Var(initialize=1.5)
model.x3_20 = Var(bounds=(0.0,6.2831854))
model.x1_21 = Var()
model.x2_21 = Var(initialize=1.5)
model.x3_21 = Var(bounds=(0.0,6.2831854))
model.x1_22 = Var()
model.x2_22 = Var(initialize=1.5)
model.x3_22 = Var(bounds=(0.0,6.2831854))
model.x1_23 = Var()
model.x2_23 = Var(initialize=1.5)
model.x3_23 = Var(bounds=(0.0,6.2831854))
model.x1_24 = Var()
model.x2_24 = Var(initialize=1.5)
model.x3_24 = Var(bounds=(0.0,6.2831854))
model.x1_25 = Var()
model.x2_25 = Var(initialize=1.5)
model.x3_25 = Var(bounds=(0.0,6.2831854))
model.x1_26 = Var()
model.x2_26 = Var(initialize=1.5)
model.x3_26 = Var(bounds=(0.0,6.2831854))
model.x1_27 = Var()
model.x2_27 = Var(initialize=1.5)
model.x3_27 = Var(bounds=(0.0,6.2831854))
model.x1_28 = Var()
model.x2_28 = Var(initialize=1.5)
model.x3_28 = Var(bounds=(0.0,6.2831854))
model.x1_29 = Var()
model.x2_29 = Var(initialize=1.5)
model.x3_29 = Var(bounds=(0.0,6.2831854))
model.x1_30 = Var()
model.x2_30 = Var(initialize=1.5)
model.x3_30 = Var(bounds=(0.0,6.2831854))
model.x1_31 = Var()
model.x2_31 = Var(initialize=1.5)
model.x3_31 = Var(bounds=(0.0,6.2831854))
model.x1_32 = Var()
model.x2_32 = Var(initialize=1.5)
model.x3_32 = Var(bounds=(0.0,6.2831854))
model.x1_33 = Var()
model.x2_33 = Var(initialize=1.5)
model.x3_33 = Var(bounds=(0.0,6.2831854))
model.x1_34 = Var()
model.x2_34 = Var(initialize=1.5)
model.x3_34 = Var(bounds=(0.0,6.2831854))
model.x1_35 = Var()
model.x2_35 = Var(initialize=1.5)
model.x3_35 = Var(bounds=(0.0,6.2831854))
model.x1_36 = Var()
model.x2_36 = Var(initialize=1.5)
model.x3_36 = Var(bounds=(0.0,6.2831854))
model.x1_37 = Var()
model.x2_37 = Var(initialize=1.5)
model.x3_37 = Var(bounds=(0.0,6.2831854))
model.x1_38 = Var()
model.x2_38 = Var(initialize=1.5)
model.x3_38 = Var(bounds=(0.0,6.2831854))
model.x1_39 = Var()
model.x2_39 = Var(initialize=1.5)
model.x3_39 = Var(bounds=(0.0,6.2831854))
model.x1_40 = Var()
model.x2_40 = Var(initialize=1.5)
model.x3_40 = Var(bounds=(0.0,6.2831854))
model.x1_41 = Var()
model.x2_41 = Var(initialize=1.5)
model.x3_41 = Var(bounds=(0.0,6.2831854))
model.x1_42 = Var()
model.x2_42 = Var(initialize=1.5)
model.x3_42 = Var(bounds=(0.0,6.2831854))
model.x1_43 = Var()
model.x2_43 = Var(initialize=1.5)
model.x3_43 = Var(bounds=(0.0,6.2831854))
model.x1_44 = Var()
model.x2_44 = Var(initialize=1.5)
model.x3_44 = Var(bounds=(0.0,6.2831854))
model.x1_45 = Var()
model.x2_45 = Var(initialize=1.5)
model.x3_45 = Var(bounds=(0.0,6.2831854))
model.x1_46 = Var()
model.x2_46 = Var(initialize=1.5)
model.x3_46 = Var(bounds=(0.0,6.2831854))
model.x1_47 = Var()
model.x2_47 = Var(initialize=1.5)
model.x3_47 = Var(bounds=(0.0,6.2831854))
model.x1_48 = Var()
model.x2_48 = Var(initialize=1.5)
model.x3_48 = Var(bounds=(0.0,6.2831854))
model.x1_49 = Var()
model.x2_49 = Var(initialize=1.5)
model.x3_49 = Var(bounds=(0.0,6.2831854))
model.x1_50 = Var()
model.x2_50 = Var(initialize=1.09905)
model.x3_50 = Var(bounds=(0.0,6.2831854))
model.u0 = Var(bounds=(0.08,0.417))
model.u1 = Var(bounds=(0.08,0.417))
model.u2 = Var(bounds=(0.08,0.417))
model.u3 = Var(bounds=(0.08,0.417))
model.u4 = Var(bounds=(0.08,0.417))
model.u5 = Var(bounds=(0.08,0.417))
model.u6 = Var(bounds=(0.08,0.417))
model.u7 = Var(bounds=(0.08,0.417))
model.u8 = Var(bounds=(0.08,0.417))
model.u9 = Var(bounds=(0.08,0.417))
model.u10 = Var(bounds=(0.08,0.417))
model.u11 = Var(bounds=(0.08,0.417))
model.u12 = Var(bounds=(0.08,0.417))
model.u13 = Var(bounds=(0.08,0.417))
model.u14 = Var(bounds=(0.08,0.417))
model.u15 = Var(bounds=(0.08,0.417))
model.u16 = Var(bounds=(0.08,0.417))
model.u17 = Var(bounds=(0.08,0.417))
model.u18 = Var(bounds=(0.08,0.417))
model.u19 = Var(bounds=(0.08,0.417))
model.u20 = Var(bounds=(0.08,0.417))
model.u21 = Var(bounds=(0.08,0.417))
model.u22 = Var(bounds=(0.08,0.417))
model.u23 = Var(bounds=(0.08,0.417))
model.u24 = Var(bounds=(0.08,0.417))
model.u25 = Var(bounds=(0.08,0.417))
model.u26 = Var(bounds=(0.08,0.417))
model.u27 = Var(bounds=(0.08,0.417))
model.u28 = Var(bounds=(0.08,0.417))
model.u29 = Var(bounds=(0.08,0.417))
model.u30 = Var(bounds=(0.08,0.417))
model.u31 = Var(bounds=(0.08,0.417))
model.u32 = Var(bounds=(0.08,0.417))
model.u33 = Var(bounds=(0.08,0.417))
model.u34 = Var(bounds=(0.08,0.417))
model.u35 = Var(bounds=(0.08,0.417))
model.u36 = Var(bounds=(0.08,0.417))
model.u37 = Var(bounds=(0.08,0.417))
model.u38 = Var(bounds=(0.08,0.417))
model.u39 = Var(bounds=(0.08,0.417))
model.u40 = Var(bounds=(0.08,0.417))
model.u41 = Var(bounds=(0.08,0.417))
model.u42 = Var(bounds=(0.08,0.417))
model.u43 = Var(bounds=(0.08,0.417))
model.u44 = Var(bounds=(0.08,0.417))
model.u45 = Var(bounds=(0.08,0.417))
model.u46 = Var(bounds=(0.08,0.417))
model.u47 = Var(bounds=(0.08,0.417))
model.u48 = Var(bounds=(0.08,0.417))
model.u49 = Var(bounds=(0.08,0.417))
model.u50 = Var(bounds=(0.08,0.417))

model.obj = Objective(expr=model.x1_50)

model.c1_1 = Constraint(expr=0.00437*(cos(model.x3_1)) / (1.62079*(0.01+0.3*model.u1*model.u1)*model.x2_1*model.x2_1) + model.x1_0 - model.x1_1 == 0)
model.c2_1 = Constraint(expr=-1.0 / model.x2_1 - (cos(model.x3_1)) / (1.62079*(0.01+0.3*model.u1*model.u1)*(model.x2_1*model.x2_1)*model.x2_1) == 0)
model.c3_1 = Constraint(expr=0.00437*model.u1 / ((0.01+0.3*model.u1*model.u1) * (model.x2_1*model.x2_1) )  - 0.00437*(cos(model.x3_1)) / (1.62079*(0.01+0.3*model.u1*model.u1)*(model.x2_1*model.x2_1)*model.x2_1*model.x2_1) + 0.1*model.x3_0 - 0.1*model.x3_1 == 0)
model.c1_2 = Constraint(expr=0.00437*(cos(model.x3_2)) / (1.62079*(0.01+0.3*model.u2*model.u2)*model.x2_2*model.x2_2) + model.x1_1 - model.x1_2 == 0)
model.c2_2 = Constraint(expr=-1.0 / model.x2_2 - (cos(model.x3_2)) / (1.62079*(0.01+0.3*model.u2*model.u2)*(model.x2_2*model.x2_2)*model.x2_2) == 0)
model.c3_2 = Constraint(expr=0.00437*model.u2 / ((0.01+0.3*model.u2*model.u2) * (model.x2_2*model.x2_2) )  - 0.00437*(cos(model.x3_2)) / (1.62079*(0.01+0.3*model.u2*model.u2)*(model.x2_2*model.x2_2)*model.x2_2*model.x2_2) + 0.1*model.x3_1 - 0.1*model.x3_2 == 0)
model.c1_3 = Constraint(expr=0.00437*(cos(model.x3_3)) / (1.62079*(0.01+0.3*model.u3*model.u3)*model.x2_3*model.x2_3) + model.x1_2 - model.x1_3 == 0)
model.c2_3 = Constraint(expr=-1.0 / model.x2_3 - (cos(model.x3_3)) / (1.62079*(0.01+0.3*model.u3*model.u3)*(model.x2_3*model.x2_3)*model.x2_3) == 0)
model.c3_3 = Constraint(expr=0.00437*model.u3 / ((0.01+0.3*model.u3*model.u3) * (model.x2_3*model.x2_3) )  - 0.00437*(cos(model.x3_3)) / (1.62079*(0.01+0.3*model.u3*model.u3)*(model.x2_3*model.x2_3)*model.x2_3*model.x2_3) + 0.1*model.x3_2 - 0.1*model.x3_3 == 0)
model.c1_4 = Constraint(expr=0.00437*(cos(model.x3_4)) / (1.62079*(0.01+0.3*model.u4*model.u4)*model.x2_4*model.x2_4) + model.x1_3 - model.x1_4 == 0)
model.c2_4 = Constraint(expr=-1.0 / model.x2_4 - (cos(model.x3_4)) / (1.62079*(0.01+0.3*model.u4*model.u4)*(model.x2_4*model.x2_4)*model.x2_4) == 0)
model.c3_4 = Constraint(expr=0.00437*model.u4 / ((0.01+0.3*model.u4*model.u4) * (model.x2_4*model.x2_4) )  - 0.00437*(cos(model.x3_4)) / (1.62079*(0.01+0.3*model.u4*model.u4)*(model.x2_4*model.x2_4)*model.x2_4*model.x2_4) + 0.1*model.x3_3 - 0.1*model.x3_4 == 0)
model.c1_5 = Constraint(expr=0.00437*(cos(model.x3_5)) / (1.62079*(0.01+0.3*model.u5*model.u5)*model.x2_5*model.x2_5) + model.x1_4 - model.x1_5 == 0)
model.c2_5 = Constraint(expr=-1.0 / model.x2_5 - (cos(model.x3_5)) / (1.62079*(0.01+0.3*model.u5*model.u5)*(model.x2_5*model.x2_5)*model.x2_5) == 0)
model.c3_5 = Constraint(expr=0.00437*model.u5 / ((0.01+0.3*model.u5*model.u5) * (model.x2_5*model.x2_5) )  - 0.00437*(cos(model.x3_5)) / (1.62079*(0.01+0.3*model.u5*model.u5)*(model.x2_5*model.x2_5)*model.x2_5*model.x2_5) + 0.1*model.x3_4 - 0.1*model.x3_5 == 0)
model.c1_6 = Constraint(expr=0.00437*(cos(model.x3_6)) / (1.62079*(0.01+0.3*model.u6*model.u6)*model.x2_6*model.x2_6) + model.x1_5 - model.x1_6 == 0)
model.c2_6 = Constraint(expr=-1.0 / model.x2_6 - (cos(model.x3_6)) / (1.62079*(0.01+0.3*model.u6*model.u6)*(model.x2_6*model.x2_6)*model.x2_6) == 0)
model.c3_6 = Constraint(expr=0.00437*model.u6 / ((0.01+0.3*model.u6*model.u6) * (model.x2_6*model.x2_6) )  - 0.00437*(cos(model.x3_6)) / (1.62079*(0.01+0.3*model.u6*model.u6)*(model.x2_6*model.x2_6)*model.x2_6*model.x2_6) + 0.1*model.x3_5 - 0.1*model.x3_6 == 0)
model.c1_7 = Constraint(expr=0.00437*(cos(model.x3_7)) / (1.62079*(0.01+0.3*model.u7*model.u7)*model.x2_7*model.x2_7) + model.x1_6 - model.x1_7 == 0)
model.c2_7 = Constraint(expr=-1.0 / model.x2_7 - (cos(model.x3_7)) / (1.62079*(0.01+0.3*model.u7*model.u7)*(model.x2_7*model.x2_7)*model.x2_7) == 0)
model.c3_7 = Constraint(expr=0.00437*model.u7 / ((0.01+0.3*model.u7*model.u7) * (model.x2_7*model.x2_7) )  - 0.00437*(cos(model.x3_7)) / (1.62079*(0.01+0.3*model.u7*model.u7)*(model.x2_7*model.x2_7)*model.x2_7*model.x2_7) + 0.1*model.x3_6 - 0.1*model.x3_7 == 0)
model.c1_8 = Constraint(expr=0.00437*(cos(model.x3_8)) / (1.62079*(0.01+0.3*model.u8*model.u8)*model.x2_8*model.x2_8) + model.x1_7 - model.x1_8 == 0)
model.c2_8 = Constraint(expr=-1.0 / model.x2_8 - (cos(model.x3_8)) / (1.62079*(0.01+0.3*model.u8*model.u8)*(model.x2_8*model.x2_8)*model.x2_8) == 0)
model.c3_8 = Constraint(expr=0.00437*model.u8 / ((0.01+0.3*model.u8*model.u8) * (model.x2_8*model.x2_8) )  - 0.00437*(cos(model.x3_8)) / (1.62079*(0.01+0.3*model.u8*model.u8)*(model.x2_8*model.x2_8)*model.x2_8*model.x2_8) + 0.1*model.x3_7 - 0.1*model.x3_8 == 0)
model.c1_9 = Constraint(expr=0.00437*(cos(model.x3_9)) / (1.62079*(0.01+0.3*model.u9*model.u9)*model.x2_9*model.x2_9) + model.x1_8 - model.x1_9 == 0)
model.c2_9 = Constraint(expr=-1.0 / model.x2_9 - (cos(model.x3_9)) / (1.62079*(0.01+0.3*model.u9*model.u9)*(model.x2_9*model.x2_9)*model.x2_9) == 0)
model.c3_9 = Constraint(expr=0.00437*model.u9 / ((0.01+0.3*model.u9*model.u9) * (model.x2_9*model.x2_9) )  - 0.00437*(cos(model.x3_9)) / (1.62079*(0.01+0.3*model.u9*model.u9)*(model.x2_9*model.x2_9)*model.x2_9*model.x2_9) + 0.1*model.x3_8 - 0.1*model.x3_9 == 0)
model.c1_10 = Constraint(expr=0.00437*(cos(model.x3_10)) / (1.62079*(0.01+0.3*model.u10*model.u10)*model.x2_10*model.x2_10) + model.x1_9 - model.x1_10 == 0)
model.c2_10 = Constraint(expr=-1.0 / model.x2_10 - (cos(model.x3_10)) / (1.62079*(0.01+0.3*model.u10*model.u10)*(model.x2_10*model.x2_10)*model.x2_10) == 0)
model.c3_10 = Constraint(expr=0.00437*model.u10 / ((0.01+0.3*model.u10*model.u10) * (model.x2_10*model.x2_10) )  - 0.00437*(cos(model.x3_10)) / (1.62079*(0.01+0.3*model.u10*model.u10)*(model.x2_10*model.x2_10)*model.x2_10*model.x2_10) + 0.1*model.x3_9 - 0.1*model.x3_10 == 0)
model.c1_11 = Constraint(expr=0.00437*(cos(model.x3_11)) / (1.62079*(0.01+0.3*model.u11*model.u11)*model.x2_11*model.x2_11) + model.x1_10 - model.x1_11 == 0)
model.c2_11 = Constraint(expr=-1.0 / model.x2_11 - (cos(model.x3_11)) / (1.62079*(0.01+0.3*model.u11*model.u11)*(model.x2_11*model.x2_11)*model.x2_11) == 0)
model.c3_11 = Constraint(expr=0.00437*model.u11 / ((0.01+0.3*model.u11*model.u11) * (model.x2_11*model.x2_11) )  - 0.00437*(cos(model.x3_11)) / (1.62079*(0.01+0.3*model.u11*model.u11)*(model.x2_11*model.x2_11)*model.x2_11*model.x2_11) + 0.1*model.x3_10 - 0.1*model.x3_11 == 0)
model.c1_12 = Constraint(expr=0.00437*(cos(model.x3_12)) / (1.62079*(0.01+0.3*model.u12*model.u12)*model.x2_12*model.x2_12) + model.x1_11 - model.x1_12 == 0)
model.c2_12 = Constraint(expr=-1.0 / model.x2_12 - (cos(model.x3_12)) / (1.62079*(0.01+0.3*model.u12*model.u12)*(model.x2_12*model.x2_12)*model.x2_12) == 0)
model.c3_12 = Constraint(expr=0.00437*model.u12 / ((0.01+0.3*model.u12*model.u12) * (model.x2_12*model.x2_12) )  - 0.00437*(cos(model.x3_12)) / (1.62079*(0.01+0.3*model.u12*model.u12)*(model.x2_12*model.x2_12)*model.x2_12*model.x2_12) + 0.1*model.x3_11 - 0.1*model.x3_12 == 0)
model.c1_13 = Constraint(expr=0.00437*(cos(model.x3_13)) / (1.62079*(0.01+0.3*model.u13*model.u13)*model.x2_13*model.x2_13) + model.x1_12 - model.x1_13 == 0)
model.c2_13 = Constraint(expr=-1.0 / model.x2_13 - (cos(model.x3_13)) / (1.62079*(0.01+0.3*model.u13*model.u13)*(model.x2_13*model.x2_13)*model.x2_13) == 0)
model.c3_13 = Constraint(expr=0.00437*model.u13 / ((0.01+0.3*model.u13*model.u13) * (model.x2_13*model.x2_13) )  - 0.00437*(cos(model.x3_13)) / (1.62079*(0.01+0.3*model.u13*model.u13)*(model.x2_13*model.x2_13)*model.x2_13*model.x2_13) + 0.1*model.x3_12 - 0.1*model.x3_13 == 0)
model.c1_14 = Constraint(expr=0.00437*(cos(model.x3_14)) / (1.62079*(0.01+0.3*model.u14*model.u14)*model.x2_14*model.x2_14) + model.x1_13 - model.x1_14 == 0)
model.c2_14 = Constraint(expr=-1.0 / model.x2_14 - (cos(model.x3_14)) / (1.62079*(0.01+0.3*model.u14*model.u14)*(model.x2_14*model.x2_14)*model.x2_14) == 0)
model.c3_14 = Constraint(expr=0.00437*model.u14 / ((0.01+0.3*model.u14*model.u14) * (model.x2_14*model.x2_14) )  - 0.00437*(cos(model.x3_14)) / (1.62079*(0.01+0.3*model.u14*model.u14)*(model.x2_14*model.x2_14)*model.x2_14*model.x2_14) + 0.1*model.x3_13 - 0.1*model.x3_14 == 0)
model.c1_15 = Constraint(expr=0.00437*(cos(model.x3_15)) / (1.62079*(0.01+0.3*model.u15*model.u15)*model.x2_15*model.x2_15) + model.x1_14 - model.x1_15 == 0)
model.c2_15 = Constraint(expr=-1.0 / model.x2_15 - (cos(model.x3_15)) / (1.62079*(0.01+0.3*model.u15*model.u15)*(model.x2_15*model.x2_15)*model.x2_15) == 0)
model.c3_15 = Constraint(expr=0.00437*model.u15 / ((0.01+0.3*model.u15*model.u15) * (model.x2_15*model.x2_15) )  - 0.00437*(cos(model.x3_15)) / (1.62079*(0.01+0.3*model.u15*model.u15)*(model.x2_15*model.x2_15)*model.x2_15*model.x2_15) + 0.1*model.x3_14 - 0.1*model.x3_15 == 0)
model.c1_16 = Constraint(expr=0.00437*(cos(model.x3_16)) / (1.62079*(0.01+0.3*model.u16*model.u16)*model.x2_16*model.x2_16) + model.x1_15 - model.x1_16 == 0)
model.c2_16 = Constraint(expr=-1.0 / model.x2_16 - (cos(model.x3_16)) / (1.62079*(0.01+0.3*model.u16*model.u16)*(model.x2_16*model.x2_16)*model.x2_16) == 0)
model.c3_16 = Constraint(expr=0.00437*model.u16 / ((0.01+0.3*model.u16*model.u16) * (model.x2_16*model.x2_16) )  - 0.00437*(cos(model.x3_16)) / (1.62079*(0.01+0.3*model.u16*model.u16)*(model.x2_16*model.x2_16)*model.x2_16*model.x2_16) + 0.1*model.x3_15 - 0.1*model.x3_16 == 0)
model.c1_17 = Constraint(expr=0.00437*(cos(model.x3_17)) / (1.62079*(0.01+0.3*model.u17*model.u17)*model.x2_17*model.x2_17) + model.x1_16 - model.x1_17 == 0)
model.c2_17 = Constraint(expr=-1.0 / model.x2_17 - (cos(model.x3_17)) / (1.62079*(0.01+0.3*model.u17*model.u17)*(model.x2_17*model.x2_17)*model.x2_17) == 0)
model.c3_17 = Constraint(expr=0.00437*model.u17 / ((0.01+0.3*model.u17*model.u17) * (model.x2_17*model.x2_17) )  - 0.00437*(cos(model.x3_17)) / (1.62079*(0.01+0.3*model.u17*model.u17)*(model.x2_17*model.x2_17)*model.x2_17*model.x2_17) + 0.1*model.x3_16 - 0.1*model.x3_17 == 0)
model.c1_18 = Constraint(expr=0.00437*(cos(model.x3_18)) / (1.62079*(0.01+0.3*model.u18*model.u18)*model.x2_18*model.x2_18) + model.x1_17 - model.x1_18 == 0)
model.c2_18 = Constraint(expr=-1.0 / model.x2_18 - (cos(model.x3_18)) / (1.62079*(0.01+0.3*model.u18*model.u18)*(model.x2_18*model.x2_18)*model.x2_18) == 0)
model.c3_18 = Constraint(expr=0.00437*model.u18 / ((0.01+0.3*model.u18*model.u18) * (model.x2_18*model.x2_18) )  - 0.00437*(cos(model.x3_18)) / (1.62079*(0.01+0.3*model.u18*model.u18)*(model.x2_18*model.x2_18)*model.x2_18*model.x2_18) + 0.1*model.x3_17 - 0.1*model.x3_18 == 0)
model.c1_19 = Constraint(expr=0.00437*(cos(model.x3_19)) / (1.62079*(0.01+0.3*model.u19*model.u19)*model.x2_19*model.x2_19) + model.x1_18 - model.x1_19 == 0)
model.c2_19 = Constraint(expr=-1.0 / model.x2_19 - (cos(model.x3_19)) / (1.62079*(0.01+0.3*model.u19*model.u19)*(model.x2_19*model.x2_19)*model.x2_19) == 0)
model.c3_19 = Constraint(expr=0.00437*model.u19 / ((0.01+0.3*model.u19*model.u19) * (model.x2_19*model.x2_19) )  - 0.00437*(cos(model.x3_19)) / (1.62079*(0.01+0.3*model.u19*model.u19)*(model.x2_19*model.x2_19)*model.x2_19*model.x2_19) + 0.1*model.x3_18 - 0.1*model.x3_19 == 0)
model.c1_20 = Constraint(expr=0.00437*(cos(model.x3_20)) / (1.62079*(0.01+0.3*model.u20*model.u20)*model.x2_20*model.x2_20) + model.x1_19 - model.x1_20 == 0)
model.c2_20 = Constraint(expr=-1.0 / model.x2_20 - (cos(model.x3_20)) / (1.62079*(0.01+0.3*model.u20*model.u20)*(model.x2_20*model.x2_20)*model.x2_20) == 0)
model.c3_20 = Constraint(expr=0.00437*model.u20 / ((0.01+0.3*model.u20*model.u20) * (model.x2_20*model.x2_20) )  - 0.00437*(cos(model.x3_20)) / (1.62079*(0.01+0.3*model.u20*model.u20)*(model.x2_20*model.x2_20)*model.x2_20*model.x2_20) + 0.1*model.x3_19 - 0.1*model.x3_20 == 0)
model.c1_21 = Constraint(expr=0.00437*(cos(model.x3_21)) / (1.62079*(0.01+0.3*model.u21*model.u21)*model.x2_21*model.x2_21) + model.x1_20 - model.x1_21 == 0)
model.c2_21 = Constraint(expr=-1.0 / model.x2_21 - (cos(model.x3_21)) / (1.62079*(0.01+0.3*model.u21*model.u21)*(model.x2_21*model.x2_21)*model.x2_21) == 0)
model.c3_21 = Constraint(expr=0.00437*model.u21 / ((0.01+0.3*model.u21*model.u21) * (model.x2_21*model.x2_21) )  - 0.00437*(cos(model.x3_21)) / (1.62079*(0.01+0.3*model.u21*model.u21)*(model.x2_21*model.x2_21)*model.x2_21*model.x2_21) + 0.1*model.x3_20 - 0.1*model.x3_21 == 0)
model.c1_22 = Constraint(expr=0.00437*(cos(model.x3_22)) / (1.62079*(0.01+0.3*model.u22*model.u22)*model.x2_22*model.x2_22) + model.x1_21 - model.x1_22 == 0)
model.c2_22 = Constraint(expr=-1.0 / model.x2_22 - (cos(model.x3_22)) / (1.62079*(0.01+0.3*model.u22*model.u22)*(model.x2_22*model.x2_22)*model.x2_22) == 0)
model.c3_22 = Constraint(expr=0.00437*model.u22 / ((0.01+0.3*model.u22*model.u22) * (model.x2_22*model.x2_22) )  - 0.00437*(cos(model.x3_22)) / (1.62079*(0.01+0.3*model.u22*model.u22)*(model.x2_22*model.x2_22)*model.x2_22*model.x2_22) + 0.1*model.x3_21 - 0.1*model.x3_22 == 0)
model.c1_23 = Constraint(expr=0.00437*(cos(model.x3_23)) / (1.62079*(0.01+0.3*model.u23*model.u23)*model.x2_23*model.x2_23) + model.x1_22 - model.x1_23 == 0)
model.c2_23 = Constraint(expr=-1.0 / model.x2_23 - (cos(model.x3_23)) / (1.62079*(0.01+0.3*model.u23*model.u23)*(model.x2_23*model.x2_23)*model.x2_23) == 0)
model.c3_23 = Constraint(expr=0.00437*model.u23 / ((0.01+0.3*model.u23*model.u23) * (model.x2_23*model.x2_23) )  - 0.00437*(cos(model.x3_23)) / (1.62079*(0.01+0.3*model.u23*model.u23)*(model.x2_23*model.x2_23)*model.x2_23*model.x2_23) + 0.1*model.x3_22 - 0.1*model.x3_23 == 0)
model.c1_24 = Constraint(expr=0.00437*(cos(model.x3_24)) / (1.62079*(0.01+0.3*model.u24*model.u24)*model.x2_24*model.x2_24) + model.x1_23 - model.x1_24 == 0)
model.c2_24 = Constraint(expr=-1.0 / model.x2_24 - (cos(model.x3_24)) / (1.62079*(0.01+0.3*model.u24*model.u24)*(model.x2_24*model.x2_24)*model.x2_24) == 0)
model.c3_24 = Constraint(expr=0.00437*model.u24 / ((0.01+0.3*model.u24*model.u24) * (model.x2_24*model.x2_24) )  - 0.00437*(cos(model.x3_24)) / (1.62079*(0.01+0.3*model.u24*model.u24)*(model.x2_24*model.x2_24)*model.x2_24*model.x2_24) + 0.1*model.x3_23 - 0.1*model.x3_24 == 0)
model.c1_25 = Constraint(expr=0.00437*(cos(model.x3_25)) / (1.62079*(0.01+0.3*model.u25*model.u25)*model.x2_25*model.x2_25) + model.x1_24 - model.x1_25 == 0)
model.c2_25 = Constraint(expr=-1.0 / model.x2_25 - (cos(model.x3_25)) / (1.62079*(0.01+0.3*model.u25*model.u25)*(model.x2_25*model.x2_25)*model.x2_25) == 0)
model.c3_25 = Constraint(expr=0.00437*model.u25 / ((0.01+0.3*model.u25*model.u25) * (model.x2_25*model.x2_25) )  - 0.00437*(cos(model.x3_25)) / (1.62079*(0.01+0.3*model.u25*model.u25)*(model.x2_25*model.x2_25)*model.x2_25*model.x2_25) + 0.1*model.x3_24 - 0.1*model.x3_25 == 0)
model.c1_26 = Constraint(expr=0.00437*(cos(model.x3_26)) / (1.62079*(0.01+0.3*model.u26*model.u26)*model.x2_26*model.x2_26) + model.x1_25 - model.x1_26 == 0)
model.c2_26 = Constraint(expr=-1.0 / model.x2_26 - (cos(model.x3_26)) / (1.62079*(0.01+0.3*model.u26*model.u26)*(model.x2_26*model.x2_26)*model.x2_26) == 0)
model.c3_26 = Constraint(expr=0.00437*model.u26 / ((0.01+0.3*model.u26*model.u26) * (model.x2_26*model.x2_26) )  - 0.00437*(cos(model.x3_26)) / (1.62079*(0.01+0.3*model.u26*model.u26)*(model.x2_26*model.x2_26)*model.x2_26*model.x2_26) + 0.1*model.x3_25 - 0.1*model.x3_26 == 0)
model.c1_27 = Constraint(expr=0.00437*(cos(model.x3_27)) / (1.62079*(0.01+0.3*model.u27*model.u27)*model.x2_27*model.x2_27) + model.x1_26 - model.x1_27 == 0)
model.c2_27 = Constraint(expr=-1.0 / model.x2_27 - (cos(model.x3_27)) / (1.62079*(0.01+0.3*model.u27*model.u27)*(model.x2_27*model.x2_27)*model.x2_27) == 0)
model.c3_27 = Constraint(expr=0.00437*model.u27 / ((0.01+0.3*model.u27*model.u27) * (model.x2_27*model.x2_27) )  - 0.00437*(cos(model.x3_27)) / (1.62079*(0.01+0.3*model.u27*model.u27)*(model.x2_27*model.x2_27)*model.x2_27*model.x2_27) + 0.1*model.x3_26 - 0.1*model.x3_27 == 0)
model.c1_28 = Constraint(expr=0.00437*(cos(model.x3_28)) / (1.62079*(0.01+0.3*model.u28*model.u28)*model.x2_28*model.x2_28) + model.x1_27 - model.x1_28 == 0)
model.c2_28 = Constraint(expr=-1.0 / model.x2_28 - (cos(model.x3_28)) / (1.62079*(0.01+0.3*model.u28*model.u28)*(model.x2_28*model.x2_28)*model.x2_28) == 0)
model.c3_28 = Constraint(expr=0.00437*model.u28 / ((0.01+0.3*model.u28*model.u28) * (model.x2_28*model.x2_28) )  - 0.00437*(cos(model.x3_28)) / (1.62079*(0.01+0.3*model.u28*model.u28)*(model.x2_28*model.x2_28)*model.x2_28*model.x2_28) + 0.1*model.x3_27 - 0.1*model.x3_28 == 0)
model.c1_29 = Constraint(expr=0.00437*(cos(model.x3_29)) / (1.62079*(0.01+0.3*model.u29*model.u29)*model.x2_29*model.x2_29) + model.x1_28 - model.x1_29 == 0)
model.c2_29 = Constraint(expr=-1.0 / model.x2_29 - (cos(model.x3_29)) / (1.62079*(0.01+0.3*model.u29*model.u29)*(model.x2_29*model.x2_29)*model.x2_29) == 0)
model.c3_29 = Constraint(expr=0.00437*model.u29 / ((0.01+0.3*model.u29*model.u29) * (model.x2_29*model.x2_29) )  - 0.00437*(cos(model.x3_29)) / (1.62079*(0.01+0.3*model.u29*model.u29)*(model.x2_29*model.x2_29)*model.x2_29*model.x2_29) + 0.1*model.x3_28 - 0.1*model.x3_29 == 0)
model.c1_30 = Constraint(expr=0.00437*(cos(model.x3_30)) / (1.62079*(0.01+0.3*model.u30*model.u30)*model.x2_30*model.x2_30) + model.x1_29 - model.x1_30 == 0)
model.c2_30 = Constraint(expr=-1.0 / model.x2_30 - (cos(model.x3_30)) / (1.62079*(0.01+0.3*model.u30*model.u30)*(model.x2_30*model.x2_30)*model.x2_30) == 0)
model.c3_30 = Constraint(expr=0.00437*model.u30 / ((0.01+0.3*model.u30*model.u30) * (model.x2_30*model.x2_30) )  - 0.00437*(cos(model.x3_30)) / (1.62079*(0.01+0.3*model.u30*model.u30)*(model.x2_30*model.x2_30)*model.x2_30*model.x2_30) + 0.1*model.x3_29 - 0.1*model.x3_30 == 0)
model.c1_31 = Constraint(expr=0.00437*(cos(model.x3_31)) / (1.62079*(0.01+0.3*model.u31*model.u31)*model.x2_31*model.x2_31) + model.x1_30 - model.x1_31 == 0)
model.c2_31 = Constraint(expr=-1.0 / model.x2_31 - (cos(model.x3_31)) / (1.62079*(0.01+0.3*model.u31*model.u31)*(model.x2_31*model.x2_31)*model.x2_31) == 0)
model.c3_31 = Constraint(expr=0.00437*model.u31 / ((0.01+0.3*model.u31*model.u31) * (model.x2_31*model.x2_31) )  - 0.00437*(cos(model.x3_31)) / (1.62079*(0.01+0.3*model.u31*model.u31)*(model.x2_31*model.x2_31)*model.x2_31*model.x2_31) + 0.1*model.x3_30 - 0.1*model.x3_31 == 0)
model.c1_32 = Constraint(expr=0.00437*(cos(model.x3_32)) / (1.62079*(0.01+0.3*model.u32*model.u32)*model.x2_32*model.x2_32) + model.x1_31 - model.x1_32 == 0)
model.c2_32 = Constraint(expr=-1.0 / model.x2_32 - (cos(model.x3_32)) / (1.62079*(0.01+0.3*model.u32*model.u32)*(model.x2_32*model.x2_32)*model.x2_32) == 0)
model.c3_32 = Constraint(expr=0.00437*model.u32 / ((0.01+0.3*model.u32*model.u32) * (model.x2_32*model.x2_32) )  - 0.00437*(cos(model.x3_32)) / (1.62079*(0.01+0.3*model.u32*model.u32)*(model.x2_32*model.x2_32)*model.x2_32*model.x2_32) + 0.1*model.x3_31 - 0.1*model.x3_32 == 0)
model.c1_33 = Constraint(expr=0.00437*(cos(model.x3_33)) / (1.62079*(0.01+0.3*model.u33*model.u33)*model.x2_33*model.x2_33) + model.x1_32 - model.x1_33 == 0)
model.c2_33 = Constraint(expr=-1.0 / model.x2_33 - (cos(model.x3_33)) / (1.62079*(0.01+0.3*model.u33*model.u33)*(model.x2_33*model.x2_33)*model.x2_33) == 0)
model.c3_33 = Constraint(expr=0.00437*model.u33 / ((0.01+0.3*model.u33*model.u33) * (model.x2_33*model.x2_33) )  - 0.00437*(cos(model.x3_33)) / (1.62079*(0.01+0.3*model.u33*model.u33)*(model.x2_33*model.x2_33)*model.x2_33*model.x2_33) + 0.1*model.x3_32 - 0.1*model.x3_33 == 0)
model.c1_34 = Constraint(expr=0.00437*(cos(model.x3_34)) / (1.62079*(0.01+0.3*model.u34*model.u34)*model.x2_34*model.x2_34) + model.x1_33 - model.x1_34 == 0)
model.c2_34 = Constraint(expr=-1.0 / model.x2_34 - (cos(model.x3_34)) / (1.62079*(0.01+0.3*model.u34*model.u34)*(model.x2_34*model.x2_34)*model.x2_34) == 0)
model.c3_34 = Constraint(expr=0.00437*model.u34 / ((0.01+0.3*model.u34*model.u34) * (model.x2_34*model.x2_34) )  - 0.00437*(cos(model.x3_34)) / (1.62079*(0.01+0.3*model.u34*model.u34)*(model.x2_34*model.x2_34)*model.x2_34*model.x2_34) + 0.1*model.x3_33 - 0.1*model.x3_34 == 0)
model.c1_35 = Constraint(expr=0.00437*(cos(model.x3_35)) / (1.62079*(0.01+0.3*model.u35*model.u35)*model.x2_35*model.x2_35) + model.x1_34 - model.x1_35 == 0)
model.c2_35 = Constraint(expr=-1.0 / model.x2_35 - (cos(model.x3_35)) / (1.62079*(0.01+0.3*model.u35*model.u35)*(model.x2_35*model.x2_35)*model.x2_35) == 0)
model.c3_35 = Constraint(expr=0.00437*model.u35 / ((0.01+0.3*model.u35*model.u35) * (model.x2_35*model.x2_35) )  - 0.00437*(cos(model.x3_35)) / (1.62079*(0.01+0.3*model.u35*model.u35)*(model.x2_35*model.x2_35)*model.x2_35*model.x2_35) + 0.1*model.x3_34 - 0.1*model.x3_35 == 0)
model.c1_36 = Constraint(expr=0.00437*(cos(model.x3_36)) / (1.62079*(0.01+0.3*model.u36*model.u36)*model.x2_36*model.x2_36) + model.x1_35 - model.x1_36 == 0)
model.c2_36 = Constraint(expr=-1.0 / model.x2_36 - (cos(model.x3_36)) / (1.62079*(0.01+0.3*model.u36*model.u36)*(model.x2_36*model.x2_36)*model.x2_36) == 0)
model.c3_36 = Constraint(expr=0.00437*model.u36 / ((0.01+0.3*model.u36*model.u36) * (model.x2_36*model.x2_36) )  - 0.00437*(cos(model.x3_36)) / (1.62079*(0.01+0.3*model.u36*model.u36)*(model.x2_36*model.x2_36)*model.x2_36*model.x2_36) + 0.1*model.x3_35 - 0.1*model.x3_36 == 0)
model.c1_37 = Constraint(expr=0.00437*(cos(model.x3_37)) / (1.62079*(0.01+0.3*model.u37*model.u37)*model.x2_37*model.x2_37) + model.x1_36 - model.x1_37 == 0)
model.c2_37 = Constraint(expr=-1.0 / model.x2_37 - (cos(model.x3_37)) / (1.62079*(0.01+0.3*model.u37*model.u37)*(model.x2_37*model.x2_37)*model.x2_37) == 0)
model.c3_37 = Constraint(expr=0.00437*model.u37 / ((0.01+0.3*model.u37*model.u37) * (model.x2_37*model.x2_37) )  - 0.00437*(cos(model.x3_37)) / (1.62079*(0.01+0.3*model.u37*model.u37)*(model.x2_37*model.x2_37)*model.x2_37*model.x2_37) + 0.1*model.x3_36 - 0.1*model.x3_37 == 0)
model.c1_38 = Constraint(expr=0.00437*(cos(model.x3_38)) / (1.62079*(0.01+0.3*model.u38*model.u38)*model.x2_38*model.x2_38) + model.x1_37 - model.x1_38 == 0)
model.c2_38 = Constraint(expr=-1.0 / model.x2_38 - (cos(model.x3_38)) / (1.62079*(0.01+0.3*model.u38*model.u38)*(model.x2_38*model.x2_38)*model.x2_38) == 0)
model.c3_38 = Constraint(expr=0.00437*model.u38 / ((0.01+0.3*model.u38*model.u38) * (model.x2_38*model.x2_38) )  - 0.00437*(cos(model.x3_38)) / (1.62079*(0.01+0.3*model.u38*model.u38)*(model.x2_38*model.x2_38)*model.x2_38*model.x2_38) + 0.1*model.x3_37 - 0.1*model.x3_38 == 0)
model.c1_39 = Constraint(expr=0.00437*(cos(model.x3_39)) / (1.62079*(0.01+0.3*model.u39*model.u39)*model.x2_39*model.x2_39) + model.x1_38 - model.x1_39 == 0)
model.c2_39 = Constraint(expr=-1.0 / model.x2_39 - (cos(model.x3_39)) / (1.62079*(0.01+0.3*model.u39*model.u39)*(model.x2_39*model.x2_39)*model.x2_39) == 0)
model.c3_39 = Constraint(expr=0.00437*model.u39 / ((0.01+0.3*model.u39*model.u39) * (model.x2_39*model.x2_39) )  - 0.00437*(cos(model.x3_39)) / (1.62079*(0.01+0.3*model.u39*model.u39)*(model.x2_39*model.x2_39)*model.x2_39*model.x2_39) + 0.1*model.x3_38 - 0.1*model.x3_39 == 0)
model.c1_40 = Constraint(expr=0.00437*(cos(model.x3_40)) / (1.62079*(0.01+0.3*model.u40*model.u40)*model.x2_40*model.x2_40) + model.x1_39 - model.x1_40 == 0)
model.c2_40 = Constraint(expr=-1.0 / model.x2_40 - (cos(model.x3_40)) / (1.62079*(0.01+0.3*model.u40*model.u40)*(model.x2_40*model.x2_40)*model.x2_40) == 0)
model.c3_40 = Constraint(expr=0.00437*model.u40 / ((0.01+0.3*model.u40*model.u40) * (model.x2_40*model.x2_40) )  - 0.00437*(cos(model.x3_40)) / (1.62079*(0.01+0.3*model.u40*model.u40)*(model.x2_40*model.x2_40)*model.x2_40*model.x2_40) + 0.1*model.x3_39 - 0.1*model.x3_40 == 0)
model.c1_41 = Constraint(expr=0.00437*(cos(model.x3_41)) / (1.62079*(0.01+0.3*model.u41*model.u41)*model.x2_41*model.x2_41) + model.x1_40 - model.x1_41 == 0)
model.c2_41 = Constraint(expr=-1.0 / model.x2_41 - (cos(model.x3_41)) / (1.62079*(0.01+0.3*model.u41*model.u41)*(model.x2_41*model.x2_41)*model.x2_41) == 0)
model.c3_41 = Constraint(expr=0.00437*model.u41 / ((0.01+0.3*model.u41*model.u41) * (model.x2_41*model.x2_41) )  - 0.00437*(cos(model.x3_41)) / (1.62079*(0.01+0.3*model.u41*model.u41)*(model.x2_41*model.x2_41)*model.x2_41*model.x2_41) + 0.1*model.x3_40 - 0.1*model.x3_41 == 0)
model.c1_42 = Constraint(expr=0.00437*(cos(model.x3_42)) / (1.62079*(0.01+0.3*model.u42*model.u42)*model.x2_42*model.x2_42) + model.x1_41 - model.x1_42 == 0)
model.c2_42 = Constraint(expr=-1.0 / model.x2_42 - (cos(model.x3_42)) / (1.62079*(0.01+0.3*model.u42*model.u42)*(model.x2_42*model.x2_42)*model.x2_42) == 0)
model.c3_42 = Constraint(expr=0.00437*model.u42 / ((0.01+0.3*model.u42*model.u42) * (model.x2_42*model.x2_42) )  - 0.00437*(cos(model.x3_42)) / (1.62079*(0.01+0.3*model.u42*model.u42)*(model.x2_42*model.x2_42)*model.x2_42*model.x2_42) + 0.1*model.x3_41 - 0.1*model.x3_42 == 0)
model.c1_43 = Constraint(expr=0.00437*(cos(model.x3_43)) / (1.62079*(0.01+0.3*model.u43*model.u43)*model.x2_43*model.x2_43) + model.x1_42 - model.x1_43 == 0)
model.c2_43 = Constraint(expr=-1.0 / model.x2_43 - (cos(model.x3_43)) / (1.62079*(0.01+0.3*model.u43*model.u43)*(model.x2_43*model.x2_43)*model.x2_43) == 0)
model.c3_43 = Constraint(expr=0.00437*model.u43 / ((0.01+0.3*model.u43*model.u43) * (model.x2_43*model.x2_43) )  - 0.00437*(cos(model.x3_43)) / (1.62079*(0.01+0.3*model.u43*model.u43)*(model.x2_43*model.x2_43)*model.x2_43*model.x2_43) + 0.1*model.x3_42 - 0.1*model.x3_43 == 0)
model.c1_44 = Constraint(expr=0.00437*(cos(model.x3_44)) / (1.62079*(0.01+0.3*model.u44*model.u44)*model.x2_44*model.x2_44) + model.x1_43 - model.x1_44 == 0)
model.c2_44 = Constraint(expr=-1.0 / model.x2_44 - (cos(model.x3_44)) / (1.62079*(0.01+0.3*model.u44*model.u44)*(model.x2_44*model.x2_44)*model.x2_44) == 0)
model.c3_44 = Constraint(expr=0.00437*model.u44 / ((0.01+0.3*model.u44*model.u44) * (model.x2_44*model.x2_44) )  - 0.00437*(cos(model.x3_44)) / (1.62079*(0.01+0.3*model.u44*model.u44)*(model.x2_44*model.x2_44)*model.x2_44*model.x2_44) + 0.1*model.x3_43 - 0.1*model.x3_44 == 0)
model.c1_45 = Constraint(expr=0.00437*(cos(model.x3_45)) / (1.62079*(0.01+0.3*model.u45*model.u45)*model.x2_45*model.x2_45) + model.x1_44 - model.x1_45 == 0)
model.c2_45 = Constraint(expr=-1.0 / model.x2_45 - (cos(model.x3_45)) / (1.62079*(0.01+0.3*model.u45*model.u45)*(model.x2_45*model.x2_45)*model.x2_45) == 0)
model.c3_45 = Constraint(expr=0.00437*model.u45 / ((0.01+0.3*model.u45*model.u45) * (model.x2_45*model.x2_45) )  - 0.00437*(cos(model.x3_45)) / (1.62079*(0.01+0.3*model.u45*model.u45)*(model.x2_45*model.x2_45)*model.x2_45*model.x2_45) + 0.1*model.x3_44 - 0.1*model.x3_45 == 0)
model.c1_46 = Constraint(expr=0.00437*(cos(model.x3_46)) / (1.62079*(0.01+0.3*model.u46*model.u46)*model.x2_46*model.x2_46) + model.x1_45 - model.x1_46 == 0)
model.c2_46 = Constraint(expr=-1.0 / model.x2_46 - (cos(model.x3_46)) / (1.62079*(0.01+0.3*model.u46*model.u46)*(model.x2_46*model.x2_46)*model.x2_46) == 0)
model.c3_46 = Constraint(expr=0.00437*model.u46 / ((0.01+0.3*model.u46*model.u46) * (model.x2_46*model.x2_46) )  - 0.00437*(cos(model.x3_46)) / (1.62079*(0.01+0.3*model.u46*model.u46)*(model.x2_46*model.x2_46)*model.x2_46*model.x2_46) + 0.1*model.x3_45 - 0.1*model.x3_46 == 0)
model.c1_47 = Constraint(expr=0.00437*(cos(model.x3_47)) / (1.62079*(0.01+0.3*model.u47*model.u47)*model.x2_47*model.x2_47) + model.x1_46 - model.x1_47 == 0)
model.c2_47 = Constraint(expr=-1.0 / model.x2_47 - (cos(model.x3_47)) / (1.62079*(0.01+0.3*model.u47*model.u47)*(model.x2_47*model.x2_47)*model.x2_47) == 0)
model.c3_47 = Constraint(expr=0.00437*model.u47 / ((0.01+0.3*model.u47*model.u47) * (model.x2_47*model.x2_47) )  - 0.00437*(cos(model.x3_47)) / (1.62079*(0.01+0.3*model.u47*model.u47)*(model.x2_47*model.x2_47)*model.x2_47*model.x2_47) + 0.1*model.x3_46 - 0.1*model.x3_47 == 0)
model.c1_48 = Constraint(expr=0.00437*(cos(model.x3_48)) / (1.62079*(0.01+0.3*model.u48*model.u48)*model.x2_48*model.x2_48) + model.x1_47 - model.x1_48 == 0)
model.c2_48 = Constraint(expr=-1.0 / model.x2_48 - (cos(model.x3_48)) / (1.62079*(0.01+0.3*model.u48*model.u48)*(model.x2_48*model.x2_48)*model.x2_48) == 0)
model.c3_48 = Constraint(expr=0.00437*model.u48 / ((0.01+0.3*model.u48*model.u48) * (model.x2_48*model.x2_48) )  - 0.00437*(cos(model.x3_48)) / (1.62079*(0.01+0.3*model.u48*model.u48)*(model.x2_48*model.x2_48)*model.x2_48*model.x2_48) + 0.1*model.x3_47 - 0.1*model.x3_48 == 0)
model.c1_49 = Constraint(expr=0.00437*(cos(model.x3_49)) / (1.62079*(0.01+0.3*model.u49*model.u49)*model.x2_49*model.x2_49) + model.x1_48 - model.x1_49 == 0)
model.c2_49 = Constraint(expr=-1.0 / model.x2_49 - (cos(model.x3_49)) / (1.62079*(0.01+0.3*model.u49*model.u49)*(model.x2_49*model.x2_49)*model.x2_49) == 0)
model.c3_49 = Constraint(expr=0.00437*model.u49 / ((0.01+0.3*model.u49*model.u49) * (model.x2_49*model.x2_49) )  - 0.00437*(cos(model.x3_49)) / (1.62079*(0.01+0.3*model.u49*model.u49)*(model.x2_49*model.x2_49)*model.x2_49*model.x2_49) + 0.1*model.x3_48 - 0.1*model.x3_49 == 0)
model.c1_50 = Constraint(expr=0.00437*(cos(model.x3_50)) / (1.62079*(0.01+0.3*model.u50*model.u50)*model.x2_50*model.x2_50) + model.x1_49 - model.x1_50 == 0)
model.c2_50 = Constraint(expr=-1.0 / model.x2_50 - (cos(model.x3_50)) / (1.62079*(0.01+0.3*model.u50*model.u50)*(model.x2_50*model.x2_50)*model.x2_50) == 0)
model.c3_50 = Constraint(expr=0.00437*model.u50 / ((0.01+0.3*model.u50*model.u50) * (model.x2_50*model.x2_50) )  - 0.00437*(cos(model.x3_50)) / (1.62079*(0.01+0.3*model.u50*model.u50)*(model.x2_50*model.x2_50)*model.x2_50*model.x2_50) + 0.1*model.x3_49 - 0.1*model.x3_50 == 0)
