#  _________________________________________________________________________
#
#  Coopr: A COmmon Optimization Python Repository
#  Copyright (c) 2010 Sandia Corporation.
#  This software is distributed under the BSD License.
#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
#  the U.S. Government retains certain rights in this software.
#  For more information, see the Coopr README.txt file.
#  _________________________________________________________________________
#
#  Formulated in pyomo by Logan Barnes and Gabe Hackebeil. Taken from:

# AMPL Model by Hande Y. Benson
#
# Copyright (C) 2001 Princeton University
# All Rights Reserved
#
# Permission to use, copy, modify, and distribute this software and
# its documentation for any purpose and without fee is hereby
# granted, provided that the above copyright notice appear in all
# copies and that the copyright notice and this
# permission notice appear in all supporting documentation.                     

#   Source:
#   A. Lewis, private communication.

#   SIF input: A.R. Conn and Ph. Toint, March 1990.

#   classification QOR2-AN-6-9

from coopr.pyomo import *
model = ConcreteModel()

N = 6
DEG = 3
PEN = 1e4

model.range1 = RangeSet(0,N-1)
model.range2 = RangeSet(0,DEG-1)

def c_index_init(model):
    return [(i,j) for i in xrange(0,DEG) for j in xrange(i,N)]
model.c_index = Set(dimen=2,ordered=True,rule=c_index_init)

def c_rule(model,i,j):
    if i == 0:
        return 1.0
    else:
        return model.c[i-1,j]*j
model.c = Param(model.c_index,rule=c_rule)

def ct_rule(model,i):
    if i == 0:
        return -1.0
    else:
        return model.ct[i-1] * (N-(i+1))
model.ct = Param(RangeSet(0,DEG-1),rule=ct_rule)

model.a = Var(model.range1,bounds=(-10,10))
model.a[0] = -1.0
model.a[1] = 1.0
model.a[2] = 1.0
model.a[3] = 0.0
model.a[4] = 1.0
model.a[5] = -1.0

model.f = Objective(expr=sum(model.a[j]**2 for j in model.range1))

model.cons1 = Constraint(expr=sum(model.a[j]*model.c[0,j] for j in model.range1)-model.ct[0] == 0)

def cons2_rule(model,i):
    return sum(model.a[j]*model.c[i,j] for j in xrange(i,N)) - model.ct[i] == 0
model.cons2 = Constraint(xrange(1,DEG),rule=cons2_rule)

def cons3_rule(model,j):
    return (model.a[j]**3-model.a[j])/PEN == 0
model.cons3 = Constraint(model.range1,rule=cons3_rule)
