#  _________________________________________________________________________
#
#  Coopr: A COmmon Optimization Python Repository
#  Copyright (c) 2010 Sandia Corporation.
#  This software is distributed under the BSD License.
#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
#  the U.S. Government retains certain rights in this software.
#  For more information, see the Coopr README.txt file.
#  _________________________________________________________________________

# Formulated in Pyomo by Gabe Hackebeil

#
#**************************
# SET UP THE INITIAL DATA *
#**************************
#   Problem :
#   *********
#   The Chebyquad problem using the exact formula for the
#   shifted chebyshev polynomials.
#   The Hessian is full.
#   Source: problem 35 in
#   J.J. More', B.S. Garbow and K.E. Hillstrom,
#   "Testing Unconstrained Optimization Software",
#   ACM Transactions on Mathematical Software, vol. 7(1), pp. 17-41, 1981.
#   See also Buckley#133 (p. 44).
#   SIF input: Nick Gould, March 1990.
#   classification SBR2-AN-V-0
#   Number of variables
#IE N                   2
#IE N                   4
#IE N                   5
#IE N                   6
#IE N                   7
#IE N                   8
#IE N                   9
#IE N                   10
#IE N                   20
#   Other parameters
#  The constants are the (0,1) average values of the Chebyshev
#  polynomials. Analytic expressions are known for these values.
#  Odd averages are zero.
#  Even averages are -1/(i**2 -1}
#   defaults = variables in (0, 1)
#  The elements are the i-th (shifted) chebyshev polynomial
#  evaluated at the j-th variable.
#   Solution
#LO SOLTN(2)            0.0
#LO SOLTN(4)            0.0
#LO SOLTN(5)            0.0
#LO SOLTN(6)            0.0
#LO SOLTN(7)            0.0
#LO SOLTN(8)            3.516874D-3
#LO SOLTN(9)            0.0
#LO SOLTN(10)           4.772713D-3
#LO SOLTN(20)           4.572955D-3
from coopr.pyomo import *
model = ConcreteModel()

n = 50.0
m = 50.0
np1 = 1.0 + (50.0)
rn = 50.0
rnp1 = 51.0
rlast = 2499.0
rj = 50.0
start = (50.0) * (1.0 / (51.0))
ri = 50.0

model.x1 = Var(bounds=(0,1),initialize=0.0196078431372549)
model.x2 = Var(bounds=(0,1),initialize=0.0392156862745098)
model.x3 = Var(bounds=(0,1),initialize=0.058823529411764705)
model.x4 = Var(bounds=(0,1),initialize=0.0784313725490196)
model.x5 = Var(bounds=(0,1),initialize=0.09803921568627451)
model.x6 = Var(bounds=(0,1),initialize=0.11764705882352941)
model.x7 = Var(bounds=(0,1),initialize=0.13725490196078433)
model.x8 = Var(bounds=(0,1),initialize=0.1568627450980392)
model.x9 = Var(bounds=(0,1),initialize=0.1764705882352941)
model.x10 = Var(bounds=(0,1),initialize=0.19607843137254902)
model.x11 = Var(bounds=(0,1),initialize=0.21568627450980393)
model.x12 = Var(bounds=(0,1),initialize=0.23529411764705882)
model.x13 = Var(bounds=(0,1),initialize=0.2549019607843137)
model.x14 = Var(bounds=(0,1),initialize=0.27450980392156865)
model.x15 = Var(bounds=(0,1),initialize=0.29411764705882354)
model.x16 = Var(bounds=(0,1),initialize=0.3137254901960784)
model.x17 = Var(bounds=(0,1),initialize=0.3333333333333333)
model.x18 = Var(bounds=(0,1),initialize=0.3529411764705882)
model.x19 = Var(bounds=(0,1),initialize=0.37254901960784315)
model.x20 = Var(bounds=(0,1),initialize=0.39215686274509803)
model.x21 = Var(bounds=(0,1),initialize=0.4117647058823529)
model.x22 = Var(bounds=(0,1),initialize=0.43137254901960786)
model.x23 = Var(bounds=(0,1),initialize=0.45098039215686275)
model.x24 = Var(bounds=(0,1),initialize=0.47058823529411764)
model.x25 = Var(bounds=(0,1),initialize=0.49019607843137253)
model.x26 = Var(bounds=(0,1),initialize=0.5098039215686274)
model.x27 = Var(bounds=(0,1),initialize=0.5294117647058824)
model.x28 = Var(bounds=(0,1),initialize=0.5490196078431373)
model.x29 = Var(bounds=(0,1),initialize=0.5686274509803921)
model.x30 = Var(bounds=(0,1),initialize=0.5882352941176471)
model.x31 = Var(bounds=(0,1),initialize=0.6078431372549019)
model.x32 = Var(bounds=(0,1),initialize=0.6274509803921569)
model.x33 = Var(bounds=(0,1),initialize=0.6470588235294118)
model.x34 = Var(bounds=(0,1),initialize=0.6666666666666666)
model.x35 = Var(bounds=(0,1),initialize=0.6862745098039216)
model.x36 = Var(bounds=(0,1),initialize=0.7058823529411764)
model.x37 = Var(bounds=(0,1),initialize=0.7254901960784313)
model.x38 = Var(bounds=(0,1),initialize=0.7450980392156863)
model.x39 = Var(bounds=(0,1),initialize=0.7647058823529411)
model.x40 = Var(bounds=(0,1),initialize=0.7843137254901961)
model.x41 = Var(bounds=(0,1),initialize=0.803921568627451)
model.x42 = Var(bounds=(0,1),initialize=0.8235294117647058)
model.x43 = Var(bounds=(0,1),initialize=0.8431372549019608)
model.x44 = Var(bounds=(0,1),initialize=0.8627450980392157)
model.x45 = Var(bounds=(0,1),initialize=0.8823529411764706)
model.x46 = Var(bounds=(0,1),initialize=0.9019607843137255)
model.x47 = Var(bounds=(0,1),initialize=0.9215686274509803)
model.x48 = Var(bounds=(0,1),initialize=0.9411764705882353)
model.x49 = Var(bounds=(0,1),initialize=0.9607843137254902)
model.x50 = Var(bounds=(0,1),initialize=0.9803921568627451)

model.obj = Objective(expr=\
		(0.02*(cos((1.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((1.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((1.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((1.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((2.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.3333333333333333)*(0.02*(cos((2.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((2.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.3333333333333333) + \
		(0.02*(cos((3.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((3.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((3.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((3.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((4.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.06666666666666667)*(0.02*(cos((4.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((4.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.06666666666666667) + \
		(0.02*(cos((5.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((5.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((5.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((5.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((6.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.02857142857142857)*(0.02*(cos((6.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((6.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.02857142857142857) + \
		(0.02*(cos((7.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((7.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((7.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((7.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((8.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.015873015873015872)*(0.02*(cos((8.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((8.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.015873015873015872) + \
		(0.02*(cos((9.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((9.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((9.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((9.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((10.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.010101010101010102)*(0.02*(cos((10.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((10.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.010101010101010102) + \
		(0.02*(cos((11.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((11.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((11.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((11.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((12.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.006993006993006993)*(0.02*(cos((12.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((12.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.006993006993006993) + \
		(0.02*(cos((13.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((13.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((13.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((13.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((14.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.005128205128205128)*(0.02*(cos((14.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((14.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.005128205128205128) + \
		(0.02*(cos((15.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((15.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((15.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((15.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((16.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.00392156862745098)*(0.02*(cos((16.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((16.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.00392156862745098) + \
		(0.02*(cos((17.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((17.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((17.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((17.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((18.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.0030959752321981426)*(0.02*(cos((18.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((18.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.0030959752321981426) + \
		(0.02*(cos((19.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((19.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((19.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((19.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((20.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.002506265664160401)*(0.02*(cos((20.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((20.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.002506265664160401) + \
		(0.02*(cos((21.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((21.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((21.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((21.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((22.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.002070393374741201)*(0.02*(cos((22.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((22.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.002070393374741201) + \
		(0.02*(cos((23.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((23.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((23.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((23.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((24.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.0017391304347826088)*(0.02*(cos((24.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((24.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.0017391304347826088) + \
		(0.02*(cos((25.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((25.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((25.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((25.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((26.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.0014814814814814814)*(0.02*(cos((26.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((26.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.0014814814814814814) + \
		(0.02*(cos((27.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((27.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((27.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((27.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((28.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.001277139208173691)*(0.02*(cos((28.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((28.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.001277139208173691) + \
		(0.02*(cos((29.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((29.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((29.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((29.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((30.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		0.0011123470522803114)*(0.02*(cos((30.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((30.0*acos((2.0e+0*model.x50-1.0e+0))))) + 0.0011123470522803114) + \
		(0.02*(cos((31.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((31.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((31.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((31.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((32.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		9.775171065493646e-4)*(0.02*(cos((32.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((32.0*acos((2.0e+0*model.x50-1.0e+0))))) + 9.775171065493646e-4) + \
		(0.02*(cos((33.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((33.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((33.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((33.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((34.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		8.658008658008658e-4)*(0.02*(cos((34.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((34.0*acos((2.0e+0*model.x50-1.0e+0))))) + 8.658008658008658e-4) + \
		(0.02*(cos((35.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((35.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((35.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((35.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((36.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		7.722007722007722e-4)*(0.02*(cos((36.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((36.0*acos((2.0e+0*model.x50-1.0e+0))))) + 7.722007722007722e-4) + \
		(0.02*(cos((37.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((37.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((37.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((37.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((38.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		6.93000693000693e-4)*(0.02*(cos((38.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((38.0*acos((2.0e+0*model.x50-1.0e+0))))) + 6.93000693000693e-4) + \
		(0.02*(cos((39.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((39.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((39.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((39.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((40.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		6.253908692933083e-4)*(0.02*(cos((40.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((40.0*acos((2.0e+0*model.x50-1.0e+0))))) + 6.253908692933083e-4) + \
		(0.02*(cos((41.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((41.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((41.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((41.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((42.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		5.672149744753262e-4)*(0.02*(cos((42.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((42.0*acos((2.0e+0*model.x50-1.0e+0))))) + 5.672149744753262e-4) + \
		(0.02*(cos((43.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((43.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((43.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((43.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((44.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		5.16795865633075e-4)*(0.02*(cos((44.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((44.0*acos((2.0e+0*model.x50-1.0e+0))))) + 5.16795865633075e-4) + \
		(0.02*(cos((45.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((45.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((45.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((45.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((46.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		4.7281323877068556e-4)*(0.02*(cos((46.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((46.0*acos((2.0e+0*model.x50-1.0e+0))))) + 4.7281323877068556e-4) + \
		(0.02*(cos((47.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((47.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((47.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((47.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((48.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		4.342162396873644e-4)*(0.02*(cos((48.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((48.0*acos((2.0e+0*model.x50-1.0e+0))))) + 4.342162396873644e-4) + \
		(0.02*(cos((49.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x50-1.0e+0))))))*(0.02*(cos((49.0*acos((2.0e+0*model.x1-1.0e+0))))) + 0.02*(cos((49.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((49.0*acos((2.0e+0*model.x50-1.0e+0)))))) + \
		(0.02*(cos((50.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x50-1.0e+0))))) + \
		4.001600640256103e-4)*(0.02*(cos((50.0*acos((2.0e+0*model.x1-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x2-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x3-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x4-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x5-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x6-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x7-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x8-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x9-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x10-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x11-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x12-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x13-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x14-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x15-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x16-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x17-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x18-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x19-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x20-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x21-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x22-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x23-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x24-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x25-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x26-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x27-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x28-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x29-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x30-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x31-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x32-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x33-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x34-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x35-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x36-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x37-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x38-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x39-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x40-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x41-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x42-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x43-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x44-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x45-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x46-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x47-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x48-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x49-1.0e+0))))) + \
		0.02*(cos((50.0*acos((2.0e+0*model.x50-1.0e+0))))) + 4.001600640256103e-4))
